/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.survey.control');

org.ametys.survey.control.InvitationsActionButton = function(id, configuration, pluginName)
{
    org.ametys.survey.control.InvitationsActionButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.survey.control.InvitationsActionButton, org.ametys.ribbon.control.button.ActionSelectionButton, {});

org.ametys.survey.control.InvitationsActionButton.prototype.onMessage = function(messages)
{
    for (var i=0; i < messages.length; i++)
    {
        if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
        {
            var allTargets = messages[i].getTargets();
            var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(allTargets, this._testTarget.createDelegate(this));
            
            if (target != null && this._currentSurveyId != target.getParameters().id)
            {
                this._currentSurveyId = target.getParameters().id;
                this._currentLang = target.getParameters().lang;
                
                this.getElements().each(function(element) { element.setDisabled(true); element.toggle(false); element.refreshing(); });
                this.updateTooltip(this.getConfiguration()['refresh-description']);
                org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, {target: this._currentSurveyId});
            }
            else if (target == null)
            {
                this._currentSurveyId = null;
                this._currentLang = null;
                
                this.getElements().each(function(element) { element.disable(); element.toggle(false); });
            }
        }
        else if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_METADATACHANGED)
        {
            var allTargets = messages[i].getTargets();
            var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(allTargets, this._testTarget.createDelegate(this));
            
            if (target != null && this._currentSurveyId == target.getParameters().id)
            {
                this.getElements().each(function(element) { element.setDisabled(true); element.toggle(false); element.refreshing(); });
                this.updateTooltip(this.getConfiguration()['refresh-description']);
                org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, {target: this._currentSurveyId});
            }
        }
    }
}

org.ametys.survey.control.InvitationsActionButton.prototype.configurationChanged = function(params)
{
    this.getElements().each(function(element) { element.stopRefreshing(); });
    
    this._pageId = params['page-id'];
    
    var disabled = this._isDisabled(params);
    this.getElements().each(function(element) { element.setDisabled(disabled); });
    
    var tooltip = this._getTooltip(this.getConfiguration()['default-description'], params);
    this.updateTooltip(tooltip, this.getElements().get(0).iconLarge, null);
    
    this._lastParams = params;
}

org.ametys.survey.control.InvitationsActionButton.prototype._isDisabled = function(params)
{
    return params['no-private'] == 'true' || params['no-page'] == 'true' || params['no-validated'] == 'true';
}

org.ametys.survey.control.InvitationsActionButton.prototype._getTooltip = function(tooltip, params)
{
	if (params['no-private'] == 'true')
	{
		tooltip = params['no-private-description'];
	}
	else if (params['no-validated'] == 'true')
    {
        tooltip = params['no-validated-description'];
    }
	else if (params['no-page'] == 'true')
    {
        tooltip = params['no-page-description'];
    }
	else if (params['all-right'] == 'true')
	{
		tooltip = params['all-right-description'];
	}
    
    return tooltip;
}
