/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.survey.control');

org.ametys.survey.control.ScheduledOpeningActionButton = function(id, configuration, pluginName)
{
    org.ametys.survey.control.ScheduledOpeningActionButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.survey.control.ScheduledOpeningActionButton, org.ametys.ribbon.control.button.ActionSelectionButton, {});

/**
 * @private
 * @property {Map<String, String>} _lastParams The parameters received on the last refresh
 */
org.ametys.survey.control.ScheduledOpeningActionButton.prototype._lastParams;

/**
 * @private
 * @property {String[]} _currentSurveysId The surveys id currently selected or null. 
 */
org.ametys.survey.control.ScheduledOpeningActionButton.prototype._currentSurveysId;

org.ametys.survey.control.ScheduledOpeningActionButton.prototype._doReload = function()
{
	if (this._currentSurveysId.length == 0)
	{
        var iconSmall = context.contextPath + this.getConfiguration()['icon-small'];
        var iconLarge = context.contextPath + this.getConfiguration()['icon-medium'];
		this.getElements().each(function(element) { 
            element.setDisabled(true); 
            element.toggle(false);
            element.iconSmall = iconSmall;
            element.iconLarge = iconLarge;
            element.updateIcon();
        });
		this.updateTooltip(this.getConfiguration()["default-description"]);
	}
	else if (this._currentSurveysId.length == 1)
	{
		this.getElements().each(function(element) { element.setDisabled(true); element.refreshing(); });
		this.updateTooltip(this.getConfiguration()["refresh-description"]);
		org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, {targets: this._currentSurveysId});
	}
	else
	{
		this.getElements().each(function(element) { element.setDisabled(true); });
		this.updateTooltip(this.getConfiguration()["multiselection-disabled-description"]);
	}
}


org.ametys.survey.control.ScheduledOpeningActionButton.prototype.onMessage = function (messages)
{
	// SELECTION
	for (var i=messages.length - 1; i >= 0; i--)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = messages[i].getTargets();
			var allTargets = org.ametys.messagebus.message.MessageTargetHelper.findAll(targets, this.checkTarget());
			var allTargetsId = this._convertToId(allTargets);
			
			// No survey selected
			if (allTargets.length == 0)
			{
				this._currentSurveysId = [];
				this._doReload();
			}
			// A single target selected 
			else if (allTargets.length == 1)
			{
				if (this._currentSurveysId.length != 1 || allTargets[0] != this._currentSurveysId[0])
				{
					this._currentSurveysId = allTargetsId;
					this._doReload();
				}
			}
			// Too many surveys selected
			else
			{
				this._currentSurveysId = [];
				this._doReload();
			}
			
			break;
		}
	}
	
	for (var i=messages.length - 1; i >= 0; i--)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_METADATACHANGED
	        || messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_MINORMETADATACHANGED)
		{
			this._doReload();
			break;
		}
	}
}

org.ametys.survey.control.ScheduledOpeningActionButton.prototype._convertToId = function (targets)
{
	var targetsIds = [];
	for (var i = 0; i < targets.length; i++)
	{
		targetsIds.push(targets[i].getParameters()['id']);
	}
	return targetsIds;
}

org.ametys.survey.control.ScheduledOpeningActionButton.prototype.checkTarget = function ()
{
	return function (target) { return target.getType() == 'survey'; };
}

org.ametys.survey.control.ScheduledOpeningActionButton.prototype._handlingMultiple = function(tooltip, paramPrefix, params)
{
	var count = parseInt(params[paramPrefix + "-size"]);
	if (count > 0)
	{
		if (tooltip != "")
		{
			tooltip += "<br/><br/>";
		}
		
		for (var i=0; i < count; i++)
		{
			if (i != 0) 
			{
				tooltip += "<br/>";
			}
			
			tooltip += this.getConfiguration()[paramPrefix + "-start-description"];
			tooltip += params[paramPrefix + "-" + i];
			tooltip += this.getConfiguration()[paramPrefix + "-end-description"];
			
			if (params["scheduled-survey-startdate-" + i] != null)
			{
				tooltip += "<br/>";
				tooltip += this.getConfiguration()["scheduled-survey-startdate-start-description"];
				tooltip += params["scheduled-survey-startdate-" + i];
				tooltip += this.getConfiguration()["scheduled-survey-startdate-end-description"];
			}
			
			if (params["scheduled-survey-enddate-" + i] != null)
			{
				tooltip += "<br/>";
				tooltip += this.getConfiguration()["scheduled-survey-enddate-start-description"];
				tooltip += params["scheduled-survey-enddate-" + i];
				tooltip += this.getConfiguration()["scheduled-survey-enddate-end-description"];
			}
			
		}
	}
	
	return tooltip;
}

org.ametys.survey.control.ScheduledOpeningActionButton.prototype._getIcon = function(params)
{
	var nbScheduledSurveys = parseInt(params['scheduled-survey-size']);
	var nbValidSurveys = parseInt(params['scheduled-survey-valid-size']);
	var nbOutOfDateSurveys = parseInt(params['scheduled-survey-outofdate-size']);
	var nbForthComingSurveys = parseInt(params['scheduled-survey-forthcoming-size']);
	
	if (nbScheduledSurveys > 0 && nbValidSurveys > 0)
	{
		var iconSmall = context.contextPath + this.getConfiguration()['on-icon-small'];
		var iconLarge = context.contextPath + this.getConfiguration()['on-icon-medium'];
		this.getElements().each(
			function (element) 
			{
				element.iconSmall = iconSmall;
				element.iconLarge = iconLarge;
			}
		);
	}
	
	if (nbScheduledSurveys > 0 && nbForthComingSurveys > 0)
	{
		var iconSmall = context.contextPath + this.getConfiguration()['forthcoming-icon-small'];
		var iconLarge = context.contextPath + this.getConfiguration()['forthcoming-icon-medium'];
		this.getElements().each(
			function (element) 
			{
				element.iconSmall = iconSmall;
				element.iconLarge = iconLarge;
			}
		);
	}
	
	if (nbScheduledSurveys > 0 && nbOutOfDateSurveys > 0)
	{
		var iconSmall = context.contextPath + this.getConfiguration()['outofdate-icon-small'];
		var iconLarge = context.contextPath + this.getConfiguration()['outofdate-icon-medium'];
		this.getElements().each(
			function (element) 
			{
				element.iconSmall = iconSmall;
				element.iconLarge = iconLarge;
			}
		);
	}
	
	if (nbScheduledSurveys == 0)
	{
		var iconSmall = context.contextPath + this.getConfiguration()['icon-small'];
		var iconLarge = context.contextPath + this.getConfiguration()['icon-medium'];
		this.getElements().each(
			function (element) 
			{
				element.iconSmall = iconSmall;
				element.iconLarge = iconLarge;
			}
		);
	}
}

org.ametys.survey.control.ScheduledOpeningActionButton.prototype.configurationError = function(response)
{
	this.getElements().each(function(element) { element.stopRefreshing(); element.setDisabled(true); });
	this.updateTooltip(this.getConfiguration()["default-description"]);
}

org.ametys.survey.control.ScheduledOpeningActionButton.prototype.configurationChanged = function(params)
{
	this.getElements().each(function(element) { element.stopRefreshing(); });
	
	var tooltip = this._handlingMultiple(this.getConfiguration()["default-description"], "scheduled-survey-valid", params);
	tooltip = this._handlingMultiple(tooltip, "scheduled-survey-outofdate", params);
	tooltip = this._handlingMultiple(tooltip, "scheduled-survey-forthcoming", params);
	
	// Icon
	this._getIcon(params);
	
	this.getElements().each(function(element) { element.updateIcon(); });
	this.updateTooltip(tooltip, this.getElements().get(0).iconLarge, null);
	
	var nbScheduledSurveys = parseInt(params['scheduled-survey-size']);
	this.getElements().each(function(element) { element.toggle(nbScheduledSurveys > 0); });	
    this.getElements().each(function(element) { element.stopRefreshing(); element.setDisabled(false); });

	this._lastParams = params;
}
