/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.survey.control');

org.ametys.survey.control.SurveyActionButton = function(id, configuration, pluginName)
{
    org.ametys.survey.control.SurveyActionButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.survey.control.SurveyActionButton, org.ametys.ribbon.control.button.ActionSelectionButton, {});

org.ametys.survey.control.SurveyActionButton.prototype.onMessage = function(messages)
{
	for (var i=0; i < messages.length; i++)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var allTargets = messages[i].getTargets();
			var surveyTarget = org.ametys.messagebus.message.MessageTargetHelper.findFirst(allTargets, function (target) { return target.getType() == 'survey'});
			var targets = org.ametys.messagebus.message.MessageTargetHelper.findAll(allTargets, this._testTarget.createDelegate(this));

			if (targets.length == 1 || targets.length > 1 && this.getConfiguration()['enable-multiselection'] != "false")
			{
				if (this.getConfiguration()['disable-on-validation'] != 'true' && this.getConfiguration()['enable-on-validation-only'] != 'true')
				{
					this.getElements().each(function(element) { element.enable(); });
					var tooltip = this.getConfiguration()['default-description'];
					this.updateTooltip(tooltip, this.getElements().get(0).iconLarge, null);
				}
				else if (this._currentSurveyId != surveyTarget.getParameters().id)
				{
					this._currentSurveyId = surveyTarget.getParameters().id;
					
					this.getElements().each(function(element) { element.setDisabled(true); element.toggle(false); element.refreshing(); });
	                this.updateTooltip(this.getConfiguration()['refresh-description']);
	                org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, {target: this._currentSurveyId});
				}
			}
			else
			{
				this._currentSurveyId = null;
				this.getElements().each(function(element) { element.disable(); });
				var tooltip = this.getConfiguration()['default-description'] + '<br/><br/>' + this.getConfiguration()['no-selection-description'];
				this.updateTooltip(tooltip, this.getElements().get(0).iconLarge, null);
			}
		}
		else if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_METADATACHANGED || messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_WORKFLOWCHANGED)
        {
            var allTargets = messages[i].getTargets();
            var surveyTarget = org.ametys.messagebus.message.MessageTargetHelper.findFirst(allTargets, function (target) { return target.getType() == 'survey'});
			var targets = org.ametys.messagebus.message.MessageTargetHelper.findAll(allTargets, this._testTarget.createDelegate(this));

			if (targets.length == 1 || targets.length > 1 && this.getConfiguration()['enable-multiselection'] != "false")
			{
				if (surveyTarget != null && this._currentSurveyId == surveyTarget.getParameters().id)
				{
					this.getElements().each(function(element) { element.setDisabled(true); element.toggle(false); element.refreshing(); });
	                this.updateTooltip(this.getConfiguration()['refresh-description']);
	                org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, {target: this._currentSurveyId});
				}
			}
        }
			
	}
}

org.ametys.survey.control.SurveyActionButton.prototype.configurationChanged = function(params)
{
    this.getElements().each(function(element) { element.stopRefreshing(); });
    
    var tooltip = this._getTooltip(this.getConfiguration()['default-description'], params);
    
    var toggleState = this._isToggled(params);
    var disabled = this._isDisabled(params);
    
    this.getElements().each(function(element) { element.allowDepress = false; element.toggle(toggleState); });
    
    this.getElements().each(function(element) { element.setDisabled(disabled); });
    
    this.updateTooltip(tooltip, this.getElements().get(0).iconLarge, null);
    
    this._lastParams = params;
}

org.ametys.survey.control.SurveyActionButton.prototype._isToggled = function(params)
{
    return false;
}

org.ametys.survey.control.SurveyActionButton.prototype._isDisabled = function(params)
{
    return (this.getConfiguration()['disable-on-validation'] == 'true' && params['validated'] == 'true') || (this.getConfiguration()['enable-on-validation-only'] == 'true' && params['validated'] != 'true');
}

org.ametys.survey.control.SurveyActionButton.prototype._getTooltip = function(tooltip, params)
{
	if (this.getConfiguration()['disable-on-validation'] == 'true' && params['validated'] == 'true')
	{
		tooltip += '<br/><br/>' + this.getConfiguration()['disable-description'];
	}
	else if (this.getConfiguration()['enable-on-validation-only'] == 'true' && params['validated'] != 'true')
	{
		tooltip += '<br/><br/>' + this.getConfiguration()['disable-description'];
	}
		
	return tooltip;
}
